( cd opt/kde/share/doc/HTML/en/ksnapshot ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/ksnapshot ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kcontrol/kamera ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kcontrol/kamera ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kcontrol/kgamma ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kcontrol/kgamma ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kolourpaint ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kolourpaint ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/okular ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/okular ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kruler ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kruler ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/gwenview ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/gwenview ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/lib ; rm -rf libkipi.so.7 )
( cd opt/kde/lib ; ln -sf libkipi.so.7.0.0 libkipi.so.7 )
( cd opt/kde/lib ; rm -rf libkipi.so )
( cd opt/kde/lib ; ln -sf libkipi.so.7 libkipi.so )
( cd opt/kde/lib ; rm -rf libkdcraw.so.8 )
( cd opt/kde/lib ; ln -sf libkdcraw.so.8.0.0 libkdcraw.so.8 )
( cd opt/kde/lib ; rm -rf libkdcraw.so )
( cd opt/kde/lib ; ln -sf libkdcraw.so.8 libkdcraw.so )
( cd opt/kde/lib ; rm -rf libkexiv2.so.8 )
( cd opt/kde/lib ; ln -sf libkexiv2.so.8.0.0 libkexiv2.so.8 )
( cd opt/kde/lib ; rm -rf libkexiv2.so )
( cd opt/kde/lib ; ln -sf libkexiv2.so.8 libkexiv2.so )
( cd opt/kde/lib ; rm -rf libksane.so.0 )
( cd opt/kde/lib ; ln -sf libksane.so.0.2.0 libksane.so.0 )
( cd opt/kde/lib ; rm -rf libksane.so )
( cd opt/kde/lib ; ln -sf libksane.so.0 libksane.so )
( cd opt/kde/lib ; rm -rf libkolourpaint_lgpl.so.4 )
( cd opt/kde/lib ; ln -sf libkolourpaint_lgpl.so.4.4.0 libkolourpaint_lgpl.so.4 )
( cd opt/kde/lib ; rm -rf libkolourpaint_lgpl.so )
( cd opt/kde/lib ; ln -sf libkolourpaint_lgpl.so.4 libkolourpaint_lgpl.so )
( cd opt/kde/lib ; rm -rf libokularcore.so.1 )
( cd opt/kde/lib ; ln -sf libokularcore.so.1.4.0 libokularcore.so.1 )
( cd opt/kde/lib ; rm -rf libokularcore.so )
( cd opt/kde/lib ; ln -sf libokularcore.so.1 libokularcore.so )
( cd opt/kde/lib ; rm -rf libgwenviewlib.so.4 )
( cd opt/kde/lib ; ln -sf libgwenviewlib.so.4.4.0 libgwenviewlib.so.4 )
( cd opt/kde/lib ; rm -rf libgwenviewlib.so )
( cd opt/kde/lib ; ln -sf libgwenviewlib.so.4 libgwenviewlib.so )
#%% begin initialize kdegraphics-4.4.5
if [ -f /opt/kde/bin/plamo_update_kde.sh ]; then
	/bin/bash /opt/kde/bin/plamo_update_kde.sh
fi
#%% end
